Selecting optimum model weights by comparing sum relative errors
(relerr()) of weighted calibration models as
suggested by Almeida et al. (2002).
weight_select(object, add_weights, ...)# S3 method for calibration
weight_select(object, add_weights = NULL, ...)
relerr(object)
# S3 method for calibration
relerr(object)
weight_select produces a matrix with differently weighted
calibration models ordered by sum relative errors.
relerr compares the nominal concentrations with those predicted by
the calibration model.
an object of class 'calibration'.
a list of weights to be added to the default weights to be
checked. These are 1/concentration^0.5, 1/concentration^1,
1/concentration^2, 1/signal^0.5, 1/signal^1, and
1/signal^2.
further arguments passed to calibration().
Julius Albert, Kilian Kenngott, Zacharias Steinmetz
If calibration data is not homoscedastic, a weighted least squares linear
calibration model may be applied to counteract the influence of high
concentrations on the regression model. This, in turn, typically improves the
accuracy at the lower end of the calibration curve (Almeida et al., 2002).
weight_select uses sum relative errors (relerr) to
find the best weight as suggested by Almeida et al. (2002). Predefined
weights include 1/concentration^0.5, 1/concentration^1,
1/concentration^2, 1/signal^0.5, 1/signal^1, and
1/signal^2 (see calibration for details).
Almeida, A. M. D., Castel-Branco, M. M., & Falcao, A. C. (2002). Linear regression for calibration lines revisited: weighting schemes for bioanalytical methods. Journal of Chromatography B, 774(2), 215-222. tools:::Rd_expr_doi("10.1016/S1570-0232(02)00244-1").
Other calibration:
calibration(),
din32645,
icp,
matrix_effect(),
neitzel2003
data(din32645)
din <- calibration(Area ~ Conc, data = din32645)
weight_select(din)
relerr(din)
Run the code above in your browser using DataLab